@@ -29,12 +29,10 @@ def validate_resume(
     validator.allow_unknown = True  # type: ignore
 
     if validator.validate(yaml_resume):  # type: ignore
-        info_message = (
-            f"Resume in location {yaml_resume} validates to the resume_schema"
-        )
+        info_message = f"Resume validates to the resume_schema"
         validation_flag = True
         return info_message, validation_flag
     else:
-        warning_message = "The resume in location {yaml_resume} does not validate to the resume_schema\n\tErrors: {validation_error}".format(yaml_resume=yaml_resume, validation_error=validator.errors)  # type: ignore
+        warning_message = "The resume does not validate to the resume_schema\n\tErrors: {validation_error}".format(validation_error=validator.errors)  # type: ignore
         validation_flag = False
         return warning_message, validation_flag
